Method: RBPDF#SetFillColorArray
- Defined in:
-
lib/rbpdf.rb,
lib/rbpdf_encode_ok.rb,
lib/rbpdf_encode_ok2.rb
Defines the color used for all filling operations (filled rectangles and cell backgrounds). It can be expressed in RGB components or gray scale. The method can be called before the first page is created and the value is retained from page to page.
array(or ordered hash) of colors
SetFillColor()
2309 2310 2311 2312 2313 2314 2315 2316 2317 2318 2319 2320 |
# File 'lib/rbpdf.rb', line 2309 def SetFillColorArray(color) if !color.nil? color = color.values if color.is_a? Hash r = !color[0].nil? ? color[0] : -1 g = !color[1].nil? ? color[1] : -1 b = !color[2].nil? ? color[2] : -1 k = !color[3].nil? ? color[3] : -1 if r >= 0 SetFillColor(r, g, b, k) end end end |