Method: RBPDF#SetXY
- Defined in:
- lib/rbpdf.rb
#SetXY(x, y, rtloff = false) ⇒ Object Also known as: set_xy
Defines the abscissa and ordinate of the current position. If the passed values are negative, they are relative respectively to the right and bottom of the page.
- @param float :x
-
The value of the abscissa.
- @param float :y
-
The value of the ordinate.
- @param boolean :rtloff
-
if true always uses the page top-left corner as origin of axis.
- @access public
- @since 1.2
- @see
-
SetX(), SetY()
5541 5542 5543 5544 |
# File 'lib/rbpdf.rb', line 5541 def SetXY(x, y, rtloff=false) SetY(y, false, rtloff) SetX(x, rtloff) end |