Method: RBPDF#getAliasNumPage
- Defined in:
- lib/rbpdf.rb
#getAliasNumPage ⇒ Object Also known as: get_alias_num_page
Returns the string alias used for the page number. If the current font is unicode type, the returned string is surrounded by additional curly braces.
- @return string
- @access public
- @since 4.5.000 (2009-01-02)
- @see
-
AliasNbPages(), PageNo(), Footer()
11424 11425 11426 11427 11428 11429 |
# File 'lib/rbpdf.rb', line 11424 def getAliasNumPage() if (@current_font['type'] == 'TrueTypeUnicode') or (@current_font['type'] == 'cidfont0') return '{' + @alias_num_page + '}' end return @alias_num_page end |